@@ -866,18 +866,6 @@ const WindowManager = new Lang.Class({
         this.setCustomKeybindingHandler('switch-windows-backward',
                                         Shell.ActionMode.NORMAL,
                                         Lang.bind(this, this._startWindowSwitcher));
-        this.setCustomKeybindingHandler('cycle-windows',
-                                        Shell.ActionMode.NORMAL,
-                                        Lang.bind(this, this._startWindowCycler));
-        this.setCustomKeybindingHandler('cycle-windows-backward',
-                                        Shell.ActionMode.NORMAL,
-                                        Lang.bind(this, this._startWindowCycler));
-        this.setCustomKeybindingHandler('cycle-group',
-                                        Shell.ActionMode.NORMAL,
-                                        Lang.bind(this, this._startGroupCycler));
-        this.setCustomKeybindingHandler('cycle-group-backward',
-                                        Shell.ActionMode.NORMAL,
-                                        Lang.bind(this, this._startGroupCycler));
         this.setCustomKeybindingHandler('switch-panels',
                                         Shell.ActionMode.NORMAL |
                                         Shell.ActionMode.OVERVIEW |
@@ -1778,28 +1766,6 @@ const WindowManager = new Lang.Class({
             tabPopup.destroy();
     },
 
-    _startWindowCycler : function(display, screen, window, binding) {
-        /* prevent a corner case where both popups show up at once */
-        if (this._workspaceSwitcherPopup != null)
-            this._workspaceSwitcherPopup.destroy();
-
-        let tabPopup = new AltTab.WindowCyclerPopup();
-
-        if (!tabPopup.show(binding.is_reversed(), binding.get_name(), binding.get_mask()))
-            tabPopup.destroy();
-    },
-
-    _startGroupCycler : function(display, screen, window, binding) {
-        /* prevent a corner case where both popups show up at once */
-        if (this._workspaceSwitcherPopup != null)
-            this._workspaceSwitcherPopup.destroy();
-
-        let tabPopup = new AltTab.GroupCyclerPopup();
-
-        if (!tabPopup.show(binding.is_reversed(), binding.get_name(), binding.get_mask()))
-            tabPopup.destroy();
-    },
-
     _startA11ySwitcher : function(display, screen, window, binding) {
         Main.ctrlAltTabManager.popup(binding.is_reversed(), binding.get_name(), binding.get_mask());
     },
