@@ -107,8 +107,6 @@ static void recorder_set_draw_cursor (ShellRecorder *recorder,
 static void recorder_pipeline_set_caps (RecorderPipeline *pipeline);
 static void recorder_pipeline_closed   (RecorderPipeline *pipeline);
 
-static void recorder_remove_redraw_timeout (ShellRecorder *recorder);
-
 enum {
   PROP_0,
   PROP_SCREEN,
@@ -237,8 +235,6 @@ shell_recorder_finalize (GObject  *object)
   recorder_set_pipeline (recorder, NULL);
   recorder_set_file_template (recorder, NULL);
 
-  recorder_remove_redraw_timeout (recorder);
-
   g_clear_object (&recorder->a11y_settings);
 
   G_OBJECT_CLASS (shell_recorder_parent_class)->finalize (object);
@@ -321,9 +317,6 @@ recorder_fetch_cursor_image (ShellRecorder *recorder)
   guint8 *data;
 
   texture = meta_cursor_tracker_get_sprite (recorder->cursor_tracker);
-  if (!texture)
-    return;
-
   width = cogl_texture_get_width (texture);
   height = cogl_texture_get_height (texture);
   stride = 4 * width;
